float4x4 WorldViewProj : WORLDVIEWPROJ;
float4 BaseColor;

struct VS_INPUT
{
	float4 Pos : POSITION;
	float3 Normal : NORMAL;
	float4 Col : COLOR0;
	float2 TexCoord : TEXCOORD0;
};

struct VS_OUTPUT
{
	float4 Pos : POSITION;
	float4 Col : COLOR0;
	float3 Normal : TEXCOORD0;
	float2 TexCoord : TEXCOORD1;
};

/// Shader to render TR4 rooms like the tomb4.exe engine
/// Requires Metasequoia version 3.1.0
/// In the material settings, set shader to "Blinn" and check "Vertex color".
/// Transparency is not emulated.
/// Works in conjunction with a modified version of blinn_t.fx
VS_OUTPUT VS(const VS_INPUT In)
{
	VS_OUTPUT Out;
	Out.Pos = mul(In.Pos, WorldViewProj);
	/// Out.Col.xyz = In.Col.xyz;	//RGB
	
	/// tomb4.exe truncates vertex rgb as below:
	Out.Col.r = (round(In.Col.r * 32 - 0.5))/32;
	Out.Col.g = (round(In.Col.g * 32 - 0.5))/32;
	Out.Col.b = (round(In.Col.b * 32 - 0.5))/32;
	
	Out.Col.w = BaseColor.w * In.Col.w;
	Out.Normal = In.Normal;
	Out.TexCoord = In.TexCoord;
	return Out;
}

